@@ -115,6 +115,14 @@ def locate_scaffold_file(path, name):
 
 def process_parameters(parameters, context: PixieContext, runtime: PixieRuntime):
     for parameter in (parameters or []):
+        parameter_overrides = runtime.config.get('parameterOverrides')
+        if parameter_overrides:
+            p_name = parameter['name']
+            for p_override in parameter_overrides:
+                if p_name in p_override.get('names', []):
+                    utils.merge(p_override.get('overrides', {}), parameter)
+                    break
+
         parameter_options = render_options(parameter, context)
         parameter_name = parameter_options['name']
         context_source = parameter_options.get('context_source', parameter_name)
@@ -212,7 +220,7 @@ def execute_scaffold(context: PixieContext, options, runtime: PixieRuntime):
     process_parameters(job.get('parameters', []), context, runtime)
 
     if context.get('__target') is None:
-        context['__target'] = '.'
+        context['__target'] = os.getcwd()
     
     _log.debug('%s', context)
 
